***Introducing ROLE JPR Replication Code***
***Benjamin Acosta, Reyko Huang, Daniel Silverman***
***Updated 8-6-21***



***Main Text***

*Collapse Dataset for Table 1 and Figures 1-2*
use "ROLE 1.0 Data Release JPR SU21 Final.dta"
tab entrymethod, gen(entrymethod)
rename entrymethod1 entryfounded
rename entrymethod2 entryappointed
rename entrymethod3 entryelected
rename entrymethod4 entryseized
rename entrymethod5 entryunclear
tab education, gen(education)
rename education1 edunoprimary
rename education2 eduprimary
rename education3 eduhighschool
rename education4 edubachelors
rename education5 edumasters
rename education6 edudoctorate
tab religion, gen(religion)
rename religion1 christianity
rename religion2 islam
rename religion3 hinduism
rename religion4 buddhism
rename religion5 religother
rename religion6 relignone
tab deathcause, gen(deathcause)
foreach v of varlist deathcause1-deathcause10 { 
	replace `v'=0 if dead==0
}
rename deathcause1 deathnatural
rename deathcause2 deathkia
rename deathcause3 deathstassassin
rename deathcause4 deathnsassassin
rename deathcause5 deathexecuted
rename deathcause6 deathfratricide
rename deathcause7 deathaccident
rename deathcause8 deathsuicide
rename deathcause9 deathhomicide
rename deathcause10 deathexternal
tab occupation, gen(occupation)
rename occupation1 jobteacher
rename occupation2 jobjournalism
rename occupation3 joblaw
rename occupation4 jobengineer
rename occupation5 jobmedicine
rename occupation6 jobsciences
rename occupation7 jobagriculture
rename occupation8 jobmilitary
rename occupation9 jobreligion
rename occupation10 joblabor
rename occupation11 jobactivist
rename occupation12 jobpolitician
rename occupation13 jobwriter
rename occupation14 jobecon
rename occupation15 jobaristocrat
rename occupation16 jobpolice
rename occupation17 jobbusiness
rename occupation18 jobother
collapse (mean) leadercode revmodcode yearofbirth yearofdeath dead leadershipage entrymethod entryfounded entryappointed entryelected entryseized entryunclear powersharing education edunoprimary eduprimary eduhighschool edubachelors edumasters edudoctorate educwest married marriageage children religion christianity islam hinduism buddhism religother relignone family affiliation physical mental occupation jobteacher jobjournalism joblaw jobengineer jobmedicine jobsciences jobagriculture jobmilitary jobreligion joblabor jobactivist jobpolitician jobwriter jobecon jobaristocrat jobpolice jobbusiness jobother military nsmilitary combat govpost exile studyab milab workab prison assassin deathcause deathnatural deathkia deathstassassin deathnsassassin deathexecuted deathfratricide deathaccident deathsuicide deathhomicide deathexternal english polyglot (first) fullbirthname confdesc groupname, by(rolecode)
save "ROLE 1.0 Data Release JPR SU21 Final Collapsed.dta"

*Table 1/Summary Statistics*
outreg2 using SumStats.doc, replace sum(log) drop(rolecode leadercode revmodcode yearofbirth yearofdeath entrymethod education marriageage religion occupation deathcause fullbirthname confdesc groupname)

*Figure 1/Leader Education*
hist education, discrete frequency xlabel(0 "No Primary" 1 "Primary" 2 "Secondary" 3 "Bachelors" 4 "Masters" 5 "Doctorate") xtitle("") color(bluishgray8) lcolor(black) lalign(center) lwidth(thin)
graph save "Leader Education.gph"

*Figure 2/Leader Entry Age*
hist leadershipage, frequency xtitle("Age at Start of Leadership") color(bluishgray8) lcolor(black) lalign(center) lwidth(thin) xlabel(20 40 60 80 100 120)
graph save "Leader Entry Age.gph"

*Table 2/Main Models*
use "ROLE 1.0 Data Release JPR SU21 Final.dta"
eststo clear
eststo: quietly nbreg km_a rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration, cl(ccode)
outreg2 using "Introducing_ROLE_Base.doc", replace alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)
eststo: quietly nbreg km_a dynamicage education military combat rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration, cl(ccode)
outreg2 using "Introducing_ROLE_Base.doc", append alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)
eststo: quietly nbreg k_a rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration, cl(ccode)
outreg2 using "Introducing_ROLE_Base.doc", append alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)
eststo: quietly nbreg k_a dynamicage education military combat rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration, cl(ccode)
outreg2 using "Introducing_ROLE_Base.doc", append alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)

*Figure 3/Marginal Effects Plots*
quietly nbreg k_a dynamicage education military combat rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration, cl(ccode)
margins, at(education = (0(1)5)) vsquish
marginsplot, title("Education") xtitle("Rebel Leader's Level of Educational Attainment") ytitle("Predicted Number of Annual Terrorist Fatalities") graphregion(color(white)) graphregion(lcolor(white)) plotregion(lcolor(black)) xlabel(0 "None" 1 "Primary" 2 "Secondary" 3 "Bachelor's" 4 "Master's" 5 "Doctorate", angle(45))
graph save "Education_Fatalities.gph"
margins, at(combat = (0(1)1)) vsquish
marginsplot, title("Combat Experience") xtitle("Rebel Leader Has Combat Experience") ytitle("Predicted Number of Annual Terrorist Fatalities") graphregion(color(white)) graphregion(lcolor(white)) plotregion(lcolor(black)) xlabel(0 "No" 1 "Yes")
graph save "Combat_Fatalities.gph"
graph combine "Education_Fatalities.gph" "Combat_Fatalities.gph", graphregion(color(white)) graphregion(lcolor(black))
graph save "Combined_Fatalities.gph"



***Appendix***

*Table A3/Completion Status*
eststo clear
eststo: quietly logit status rgdppc xpolity stdcinc incompatibility duration intensitylevel, cl(ccode)
outreg2 using "Introducing_ROLE_Status.doc", replace alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)
eststo: quietly logit status rgdppc xpolity stdcinc incompatibility duration intensitylevel africa asia europe mena, cl(ccode)
outreg2 using "Introducing_ROLE_Status.doc", append alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)

*Table A4/Information Availability*
eststo clear
eststo: quietly nbreg km_a dynamicage education military combat rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration stdcinc intensitylevel, cl(ccode)
outreg2 using "Introducing_ROLE_GScholar.doc", replace alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)
eststo: quietly nbreg k_a dynamicage education military combat rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration stdcinc intensitylevel, cl(ccode)
outreg2 using "Introducing_ROLE_GScholar.doc", append alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)
eststo: quietly nbreg km_a dynamicage education military combat rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration gscholar, cl(ccode)
outreg2 using "Introducing_ROLE_GScholar.doc", append alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)
eststo: quietly nbreg k_a dynamicage education military combat rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration gscholar, cl(ccode)
outreg2 using "Introducing_ROLE_GScholar.doc", append alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)

*Table A5/Additional Covariates*
eststo clear
eststo: quietly nbreg km_a dynamicage education military combat rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration terrcont diaspora nagtheo prevactive africa, cl(ccode)
outreg2 using "Introducing_ROLE_Covariates.doc", replace alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)
eststo: quietly nbreg k_a dynamicage education military combat rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration terrcont diaspora nagtheo prevactive africa, cl(ccode)
outreg2 using "Introducing_ROLE_Covariates.doc", append alpha (0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) dec(2)

*Table A7/Multicollinearity Check*
reg km_a dynamicage education military combat rebstrength strengthcent nag_support finance rgdppc xpolity incompatibility duration, cl(ccode)
estat vif

